@@ -16,8 +16,7 @@ from . import exceptions
 
 class TorchTagger:
 
-    def __init__(self, embedding=None, model_arch="fastText", n_classes=2, num_epochs=5, 
-                 text_processor=TextProcessor()):
+    def __init__(self, embedding, model_arch="fastText", n_classes=2, num_epochs=5):
         # retrieve model and initial config
         self.description = None
         self.config = TORCH_MODELS[model_arch]["config"]()
@@ -28,8 +27,6 @@ class TorchTagger:
         self.config.max_epochs = num_epochs
         # statistics report for each epoch
         self.epoch_reports = []
-        # text processor
-        self.text_processor = text_processor
         # model
         self.model = None
         self.text_field = None
@@ -39,6 +36,8 @@ class TorchTagger:
         # load tokenizer and embedding for the model
         self.tokenizer = self._get_tokenizer()
         self.embedding = embedding
+        # text processor
+        self.text_processor = TextProcessor(phraser=embedding.phraser, remove_stop_words=False)
 
 
     @staticmethod
@@ -131,6 +130,7 @@ class TorchTagger:
             loaded = dill.load(file)
         # set class variables
         self._set_loaded_values(loaded)
+        self.text_processor.phraser = self.embedding.phraser
         return True
 
 
@@ -140,10 +140,7 @@ class TorchTagger:
         self.description = tagger_object.description
         tagger_path = tagger_object.model.path
         # load model
-        loaded = joblib.load(tagger_path)
-        # set class variables
-        self._set_loaded_values(loaded)
-        return True
+        return self.load(tagger_path)
     
 
     def _set_loaded_values(self, loaded):
